kedro.utils.load_obj — Kedro 0.17.6 documentation

# kedro.utils.load_obj

`kedro.utils.` `load_obj`(obj_path, default_obj_path='')

  Extract an object from a given path.

  Parameters

    - obj_path (`str`) – Path to an object to be extracted, including the object name.

    - default_obj_path (`str`) – Default object path.

  Return type

    `Any`

  Returns

    Extracted object.

  Raises

    AttributeError – When the object does not have the given named attribute.